import "Turbine.UI";
import "Turbine.UI.Lotro";
import "Simbo.NeoKhuzdul.Class"; -- Turbine library included so that there's no outside dependencies
import "Simbo.NeoKhuzdul.Localisation";
import "Simbo.NeoKhuzdul.Functions_Windows";
import "Simbo.NeoKhuzdul.StringFunctions";
import "Simbo.NeoKhuzdul.CategoryButton";
import "Simbo.NeoKhuzdul.RadioButton";
import "Simbo.NeoKhuzdul.DropdownList";
import "Simbo.NeoKhuzdul.Dictionary";
import "Simbo.NeoKhuzdul";

Settings = 
{
	NeoKhuzdulWindow =
	{
		Position = {Left = "100", Top = "100"},
		Size = {Width = "400", Height = "350"},
		WindowOpacity = "96",
		DefaultChannel = Strings["cmd_say"],
		HideTranslation = false
	},
	ToggleWindow =
	{
		Position = {Left = "100", Top = "100"},
		WindowOpacity = "96"
	}
};

Globals =
{
	Sizes =
	{
		Label = { Width = 130, Height = 24 },
		TextBox = { Width = 100, Height = 22 },
		Button = { Width = 90, Height = 24 },
		CheckBox = { Width = 200, Height = 22 },
		WideButton = { Width = 120, Height = 24 },
		DropdownList = { Width = 100, Height = 24, OpenedHeight = 120 },
		CategoryButton = 12
	},
	Fonts = 
	{
		Label = Turbine.UI.Lotro.Font.TrajanPro15,
		CategoryButton = Turbine.UI.Lotro.Font.TrajanPro14,
		TextBox = Turbine.UI.Lotro.Font.TrajanPro15,
		ListBox = Turbine.UI.Lotro.Font.TrajanPro14
	},
	Colours =
	{
		Label = Turbine.UI.Color(1.0, 1.0, 1.0, 1.0),
		CategoryButton = Turbine.UI.Color(1.0, 0.85, 0.85, 0.62),
		TextBox = Turbine.UI.Color(1.0, 1.0, 1.0, 1.0),
		ListBox = Turbine.UI.Color(1.0, 1.0, 1.0, 1.0),
		Disabled = Turbine.UI.Color(1.0, 0.33, 0.33, 0.33)
	},
	BackgroundColours =
	{
		TextBox = Turbine.UI.Color(1.0, 0, 0, 0),
		ListBox = Turbine.UI.Color(1.0, 0, 0, 0),
		RadioButton = Turbine.UI.Color(1.0, 0, 0, 0)
	},
	BorderColours =
	{
		ListBox = Turbine.UI.Color(1.0, 0.16, 0.19, 0.24)
	},
	Icons = 
	{
		Toggle = "Simbo/NeoKhuzdul/Icons/Toggle.tga",
		Toggle_Hover = "Simbo/NeoKhuzdul/Icons/Toggle_Hover.tga",
		WindowResizer = "Simbo/NeoKhuzdul/Icons/MouseDrag.tga",
		MainShortcut = "Simbo/NeoKhuzdul/Icons/MainShortcut.tga",
		MainShortcut_Hover = "Simbo/NeoKhuzdul/Icons/MainShortcut_Hover.tga",
		MainShortcut_Inactive = "Simbo/NeoKhuzdul/Icons/MainShortcut_Inactive.tga",
		Male = "Simbo/NeoKhuzdul/Icons/Male.tga",
		Female = "Simbo/NeoKhuzdul/Icons/Female.tga",
		SortedAsc = "Simbo/NeoKhuzdul/Icons/SortedAsc.tga",
		SortedAsc_Hover = "Simbo/NeoKhuzdul/Icons/SortedAsc_Hover.tga",
		SortedDesc = "Simbo/NeoKhuzdul/Icons/SortedDesc.tga",
		SortedDesc_Hover = "Simbo/NeoKhuzdul/Icons/SortedDesc_Hover.tga",
		SortedNone = "Simbo/NeoKhuzdul/Icons/SortedNone.tga",
		SortedNone_Hover = "Simbo/NeoKhuzdul/Icons/SortedNone_Hover.tga"
	}
}

NeoKhuzdulLoad = Turbine.PluginData.Load;
NeoKhuzdulSave = Turbine.PluginData.Save;

Settings = NeoKhuzdulLoad(Turbine.DataScope.Account, "NeoKhuzdulSettings") or Settings;

Settings.ToggleWindow = Settings.ToggleWindow or { Position = {Left = "100", Top = "100"}, WindowOpacity = "96" };

if Settings.NeoKhuzdulWindow.Opacity ~= nil then
	Settings.NeoKhuzdulWindow.WindowOpacity = "96";
	Settings.NeoKhuzdulWindow.Opacity = nil;
end

if Settings.ToggleWindow.Opacity ~= nil then
	Settings.ToggleWindow.WindowOpacity = "96";
	Settings.ToggleWindow.Opacity = nil;
end

khuzdulWindow = Simbo.NeoKhuzdul.NeoKhuzdulWindow();
if Settings.NeoKhuzdulWindow.Visible == nil or Settings.NeoKhuzdulWindow.Visible == "yes" then
	khuzdulWindow:SetVisible(true);
else
	khuzdulWindow:SetVisible(false);
end

toggleWindow = Simbo.NeoKhuzdul.ToggleWindow();
toggleWindow:SetVisible(true);
toggleWindow:SetZOrder(khuzdulWindow:GetZOrder() + 1);
CheckWindowPosition(toggleWindow);

if (Plugins["Neo-Khuzdul"] ~= nil ) then
	Plugins["Neo-Khuzdul"].Unload = function( sender, args )
		khuzdulWindow:SaveSettings(true);
	end
end

khuzdulCommand = Turbine.ShellCommand();

function khuzdulCommand:Execute(cmd, args)
	args = string.lower(args);

	if args == Strings["cmd_show"] then
		khuzdulWindow:Show();
	elseif args == Strings["cmd_hide"] then
		khuzdulWindow:Hide();
	elseif args == Strings["cmd_toggle"] then
		khuzdulWindow:Toggle();
	elseif args ~= nil then
		khuzdulCommand:GetHelp();
	end
end

function khuzdulCommand:GetHelp()
	Turbine.Shell.WriteLine(Strings["usage"]);
	Turbine.Shell.WriteLine(" " .. Strings["cmd_help1"]);
	Turbine.Shell.WriteLine(" " .. Strings["cmd_help2"]);
	Turbine.Shell.WriteLine(" " .. Strings["cmd_help3"]);
end

Turbine.Shell.AddCommand(Strings["cmd_neokhuzdul"], khuzdulCommand);
Turbine.Shell.WriteLine("Neo-Khuzdul v" .. Plugins["Neo-Khuzdul"]:GetVersion() .. " by Simbo");